@@ -21,7 +21,12 @@ import aws_solutions_constructs.aws_events_rule_step_function._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-s3-step-function", "1.46.0", __name__[0:-6], "aws-s3-step-function@1.46.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-s3-step-function",
+    "1.50.0",
+    __name__[0:-6],
+    "aws-s3-step-function@1.50.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
